@@ -1,11 +1,12 @@
 #' Automatic placement of calls at beggining of sound window
 #'
-#' @description Recreate each \code{".wav"} file on a given folder while placing calls at the beggining of sound window. New \code{".wav"} files will be stored on a new folder, which is automatically created.
+#' @description Recreate each \code{".wav"} file on a given folder while placing calls at the beginning of sound window. New \code{".wav"} files will be stored on a new folder, which is automatically created.
 #'
 #' @param wav.at filepath to the folder where \code{".wav"} files are stored. Should be presented between quotation marks. By default: \code{wav.at = NULL} (i.e. user must specify the filepath to \code{".wav"} files)
 #' @param wav.to name of the folder where new \code{".wav"} files will be stored. Should be presented between quotation marks. By default: \code{wav.to = "Aligned"}
 #' @param time.length intended length for the time (X-axis) in seconds. Should be a value that encompasses all sounds in the study. By default: \code{time.length = 1}
 #' @param time.perc slight time gap (in percentage) relative to the intended length that encompass all sounds in the study (i.e. \code{time.length}). Intervals are added before and after the minimum and maximum time coordinates (X-values) from the selected curve of relative amplitude (\code{dBlevel}). By default: \code{time.perc = 0.005} (i.e. 0.5%)
+#' @param flim modifications of the frequency limits (Y-axis) to focus on acoustic units. Useful for recordings with low signal-to-noise ratio. Vector with two values in kHz. By default: \code{flim = NULL}
 #' @param dBlevel absolute amplitude value to be used as relative amplitude contour, which will serve as reference for call placement. By default: \code{dBlevel = 25}
 #' @param f sampling frequency of \code{".wav"} files (in Hz). By default: \code{f = 44100}
 #' @param wl length of the window for the analysis. By default: \code{wl = 512}
@@ -54,18 +55,21 @@
 #'            time.length = 0.5, time.perc = 0.01, dBlevel = 25)
 #'
 #' # Verify alignment using eigensound function featuring analysis.type = "twoDshape"
+#' eigensound(analysis.type = "twoDshape", wav.at = file.path(wav.at, "Aligned"), store.at = store.at,
+#'            flim=c(0, 3), tlim=c(0,0.5), dBlevel = 25, plot.exp = TRUE, plot.as = "jpeg")
+#' # To see jpeg files created, check folder specified by store.at
 #'
 #' }
 #'
 #' @references
 #' MacLeod, N., Krieger, J. & Jones, K. E. (2013). Geometric morphometric approaches to acoustic signal analysis in mammalian biology. \emph{Hystrix, the Italian Journal of Mammalogy, 24}(1), 110-125.
 #'
-#' Rocha, P. & Romano, P. (\emph{in prep}) The shape of sound: A new \code{R} package that crosses the bridge between Bioacoustics and Geometric Morphometrics. \emph{Methods in Ecology and Evolution}
+#' Rocha, P. & Romano, P. (2021) The shape of sound: A new \code{R} package that crosses the bridge between Bioacoustics and Geometric Morphometrics. \emph{Methods in Ecology and Evolution, 12}(6), 1115-1121.
 #'
 #'
 #' @export
 #'
-align.wave <- function(wav.at=NULL, wav.to="Aligned", time.length=1, time.perc=0.005, dBlevel=25, f=44100, wl=512, ovlp=70)  {
+align.wave <- function(wav.at=NULL, wav.to="Aligned", time.length=1, time.perc=0.005, flim=NULL, dBlevel=25, f=44100, wl=512, ovlp=70)  {
 
   if(is.null(wav.at)) {stop("Use 'wav.at' to specify folder path where '.wav' files are stored")}
 
@@ -81,7 +85,7 @@ align.wave <- function(wav.at=NULL, wav.to="Aligned", time.length=1, time.perc=0
     orig.wav <- seewave::addsilw(orig.wav0, f=f, at="end", d=(time.length*10), output = "Wave")
 
     # create spectro object
-    orig.spec <- seewave::spectro(orig.wav, f=f, wl=wl, ovlp=ovlp, osc=F, grid=F, plot=F)
+    orig.spec <- seewave::spectro(orig.wav, f=f, wl=wl, ovlp=ovlp, osc=F, grid=F, plot=F, flim=flim)
 
     # Acquire contours
     cont.spec <- grDevices::contourLines(x=orig.spec$time, y=orig.spec$freq, z=t(orig.spec$amp),
@@ -99,7 +103,10 @@ align.wave <- function(wav.at=NULL, wav.to="Aligned", time.length=1, time.perc=0
     t.min <- min(min.spec)
     t.max <- max(max.spec)
 
-    if((t.min-(time.perc*time.length))<=0)
+    if(t.min==0)
+    stop("Background noise is likely interfering with the alighment. Consider using 'flim' argument to focus on acoustic signals")
+
+    if((t.min-(time.perc*time.length))<0)
       stop("Time percentage is too large. Consider a smaller value of 'time.perc'")
 
     # cut Wave file using minimum and maximum time values
